@@ -9,12 +9,12 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.SageMakerRuntime 1.21.30\nVersion:         1.21.30\nBuilder"
-        " version: 7.5.5\nDocs:           "
-        " https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime//\nBoto3 docs:     "
-        " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-runtime.html#SageMakerRuntime\nOther"
+        "Type annotations for boto3.SageMakerRuntime 1.23.0\nVersion:         1.23.0\nBuilder"
+        " version: 7.5.14\nDocs:           "
+        " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime//\nBoto3 docs:   "
+        "   https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-runtime.html#SageMakerRuntime\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
-        " https://github.com/vemel/mypy_boto3_builder/releases"
+        " https://github.com/youtype/mypy_boto3_builder/releases"
     )
 
 
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.21.30")
+    print("1.23.0")
 
 
 def main() -> None:
